<?php 

/**
* @file
* Administration page callbacks for the UC Role Progression module
*/

/**
* Form builder. Configure UC Role Progression
*
* @ingroup forms
* @see system_settings_form().
*/
function uc_role_progression_settings() {
  // Get an array of roles with internal names as keys and friendly names as values.
  $roles = user_roles($membersonly = TRUE, $permission = NULL);
  $options = array(0 => 'none') + $roles;
  $granularities =  array('days' => 'days', 'weeks' => 'weeks');

  // Allow user to select a role that progresses from each existing role
  foreach ($roles as $key => $value) {
    $specific_options = $options; 
    unset($specific_options[$key]);
  
    $form[$value] = array(
      '#type' => 'fieldset',
      '#title' => $value,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );  
  
    $form[$value]['uc_role_progression_' . $key] = array(
      '#type' => 'select',
      '#title' => t($value . ' is followed by'),
      '#options' =>  $specific_options,
      '#default_value' => variable_get('uc_role_progression_' . $key, array(0 => 'none')),
      '#description' => t('Select role that follows @role in progression.', array('@role' => $value)),
    );
    
    $form[$value]['uc_role_progression_prerequisites_' . $key] = array(
      '#type' => 'select',
      '#title' => t('Prerequisite roles that allow this progression'),
      '#options' =>  $roles,
      '#multiple' => TRUE,
      '#default_value' => variable_get('uc_role_progression_prerequisites_' . $key, array(2 => 'authenticated user')),
      '#description' => t('This progression is allowed if the user is a member of any of the above prerequisite roles.'),
    );
 
    $form[$value]['uc_role_progression_expiration_' . $key] = array(
      '#type' => 'textfield',
      '#title' => t('Time until role expires'),
      '#description' => t('Select the number of weeks or days (depending on selected granularity below) that this role should last before expiring and triggering another role progression. Use numeric values only.'),
      '#default_value' => variable_get('uc_role_progression_expiration_' . $key, '1'),
      '#element_validate' => array('uc_role_progression_expiration_validate'),
      '#required' => TRUE,
      '#size' => 6,
    );

    $form[$value]['uc_role_progression_granularity_' . $key] = array(
      '#type' => 'select',
      '#title' => t('Granularity used in setting time until role expires'),
      '#options' =>  $granularities,
      '#description' => t('Select the granularity used when setting time untile role expires.'),
      '#default_value' => variable_get('uc_role_progression_granularity_' . $key, array('weeks')),
    );

  }
  return system_settings_form($form);
}

// validate >= zero
function uc_role_progression_expiration_validate($element, &$form_state) {
  $value = $element['#value'];
  if ($value !== '' && (!is_numeric($value) || intval($value) != $value || $value < 0)) {
    form_error($element, t('%name must be a whole number (an integer greater then or equal to zero).', array('%name' => $element['#title'])));
  }
}
